#################################################################
#  MultiChannelCombine
#  
#  @author simon jokuschies
#  @email info@leafpictures.de
#  @version 1.0
#
#  description:
#  the script shuffles all selected readnodes together and
#  creates a write node for exporting everything as one exr file
#
#################################################################

import nuke

def MultiChannelCombine():

    images = nuke.selectedNodes()
    passes=[]
    lastPass=""
    pipe2=""
    i=0
    noread=0
    
    if len(images)>1:
        
        #check if all selected nodes are read nodes
        for img in images:
            if img.Class()!="Read":
                noread+=1 
       
        if noread==0:
            #get all the names of the selected images
            for img in images:
                
                #autoplace selected nodes
                nuke.autoplace(img)
                
                #get all the filenames to use them as pass name
                imagePath = img.knob("file").value()  
                imageSplit=imagePath.split("/")
                lastVal = imageSplit.pop()     
                #cutouts
                lastVal = lastVal.split(".")    
                passName = lastVal[0]  
                #frame padding %
                lastVal = passName.split("%")    
                passName = lastVal[0]       
                passes.append(passName)
                
                if i>0:
                    if i==1:
                        #initialize pipe2 for first round 
                        pipe2=images[0]
                   
                    #creating shuffle
                    shuffle = nuke.nodes.ShuffleCopy()
                    shuffle.setName("shuffle_"+passes[i])
                    shuffle.setInput(0, pipe2)
                    shuffle.setInput(1, images[i])
                    
                    #creating channels
                    r_temp=passes[i]+".red"
                    g_temp=passes[i]+".green"
                    b_temp=passes[i]+".blue"
                    newLayer = nuke.Layer(passes[i],[r_temp, g_temp, b_temp])        
                    
                    #setting up the shuffle nodes inputs and outputs
                    shuffle.knob("out2").setValue(passes[i])  
                    
                    shuffle['red'].setValue('red2')
                    shuffle['green'].setValue('green2')
                    shuffle['blue'].setValue('blue2') 
                    shuffle['alpha'].setValue('alpha2') 
            
                    shuffle['black'].setValue('red') 
                    shuffle['white'].setValue('green')
                    shuffle['red2'].setValue('blue') 
                    shuffle['green2'].setValue('alpha') 
                    
                    '''
                        this was a reported bug; 
                        it's right that red2 is actually called black, green2 is actually called white, blue2 is actually called red2 and alpha2 is actually called green2
                        pretty strange but it is like that
                        look here:
                        http://forums.thefoundry.co.uk/phpBB2/viewtopic.php?t=5954&sid=5eba0be48c454bf34bc7bdf301983a21  
                    '''
                    #safe last shuffle for next round to pipe it in in shuffleknob pipe2
                    pipe2 = shuffle;
             
                i+=1
            
            #create write node
            write = nuke.nodes.Write()
            lastShuffle = nuke.toNode("shuffle_"+passes[len(passes)-1])
            write.setInput(0,lastShuffle)
            write.knob("file_type").setValue("exr")   
            write.knob("channels").setValue("all")
        else:
            nuke.message("Please make sure to select READ nodes only")
    else:
        nuke.message("Please select at least 2 Read Nodes")
    
    
    
    
    

